==========================
JavaScript Extension Hooks
==========================

.. If you add to this list, make sure to also add to extending/index.rst.

.. toctree::
   :maxdepth: 1

   comment-dialog-hook
   review-dialog-comment-hook
   review-dialog-hook
